<?php
/**
 * Enqueue scripts and styles.
 *
 * @package    Pinpoint
 * @author     Theme Junkie
 * @copyright  Copyright (c) 2016, Theme Junkie
 * @license    http://www.gnu.org/licenses/gpl-2.0.html
 * @since      1.0.0
 */

/**
 * Loads the theme styles & scripts.
 *
 * @since 1.0.0
 * @link  http://codex.wordpress.org/Function_Reference/wp_enqueue_script
 * @link  http://codex.wordpress.org/Function_Reference/wp_enqueue_style
 */
function pinpoint_enqueue() {

	// Load plugins stylesheet
	wp_enqueue_style( 'pinpoint-plugins-style', trailingslashit( get_template_directory_uri() ) . 'assets/css/plugins.min.css' );

	// Fonts
	wp_enqueue_style( 'pinpoint-fonts', pinpoint_fonts_url() );

	// if WP_DEBUG and/or SCRIPT_DEBUG turned on, load the unminified styles & script.
	if ( ! is_child_theme() && WP_DEBUG || SCRIPT_DEBUG ) {

		// Load main stylesheet
		wp_enqueue_style( 'pinpoint-style', get_stylesheet_uri() );

		// Load custom js plugins.
		wp_enqueue_script( 'pinpoint-plugins', trailingslashit( get_template_directory_uri() ) . 'assets/js/plugins.min.js', array( 'jquery' ), null, true );

		// Load custom js methods.
		wp_enqueue_script( 'pinpoint-main', trailingslashit( get_template_directory_uri() ) . 'assets/js/main.js', array( 'jquery' ), null, true );

		$script_handle = 'pinpoint-main';

	} else {

		// Load main stylesheet
		wp_enqueue_style( 'pinpoint-style', trailingslashit( get_template_directory_uri() ) . 'style.min.css' );

		// Load custom js plugins.
		wp_enqueue_script( 'pinpoint-scripts', trailingslashit( get_template_directory_uri() ) . 'assets/js/pinpoint.min.js', array( 'jquery' ), null, true );

		$script_handle = 'pinpoint-scripts';

	}

	// Pass var to js
	wp_localize_script( $script_handle, 'pinpoint',
		array(
			'site_url'   => trailingslashit( get_template_directory_uri() ),
			'ajaxurl'    => admin_url( 'admin-ajax.php' ),
			'rated'      => esc_html__( 'You already like this', 'pinpoint' ),
			'endOfPages' => esc_html__( 'No more pages to load.', 'pinpoint' ),
			'imgLoader'  => trailingslashit( get_template_directory_uri() ) . 'assets/img/ajax-loader.gif',
		)
	);

	// If child theme is active, load the stylesheet.
	if ( is_child_theme() ) {
		wp_enqueue_style( 'pinpoint-child-style', get_stylesheet_uri() );
	}

	// Load comment-reply script.
	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
		wp_enqueue_script( 'comment-reply' );
	}

	// Loads HTML5 Shiv
	wp_enqueue_script( 'pinpoint-html5', trailingslashit( get_template_directory_uri() ) . 'assets/js/html5shiv.min.js', array( 'jquery' ), null, false );
	wp_script_add_data( 'pinpoint-html5', 'conditional', 'lte IE 9' );

}
add_action( 'wp_enqueue_scripts', 'pinpoint_enqueue' );
