<?php
/**
 * Custom template tags for this theme.
 * Eventually, some of the functionality here could be replaced by core features.
 *
 * @package    Pinpoint
 * @author     Theme Junkie
 * @copyright  Copyright (c) 2016, Theme Junkie
 * @license    http://www.gnu.org/licenses/gpl-2.0.html
 * @since      1.0.0
 */

if ( ! function_exists( 'pinpoint_site_branding' ) ) :
/**
 * Site branding for the site.
 *
 * Display site title by default, but user can change it with their custom logo.
 * They can upload it on Customizer page.
 *
 * @since  1.0.0
 */
function pinpoint_site_branding() {

	// Get the log.
	$logo_id  = get_theme_mod( 'custom_logo' );
	$logo_url = wp_get_attachment_image_src( $logo_id , 'full' );

	// Check if logo available, then display it.
	if ( $logo_id ) :
		echo '<a href="' . esc_url( get_home_url() ) . '" rel="home">' . "\n";
			echo '<img src="' . esc_url( $logo_url[0] ) . '" alt="' . esc_attr( get_bloginfo( 'name' ) ) . '" />' . "\n";
		echo '</a>' . "\n";

	// If not, then display the Site Title and Site Description.
	else :
		echo '<h1 class="h1 nomargin logo-text"><a href="' . esc_url( get_home_url() ) . '" rel="home">' . esc_attr( get_bloginfo( 'name' ) ) . '</a></h1>'. "\n";
		echo '<div class="tagline small muted nomargin">' . esc_attr( get_bloginfo( 'description' ) ) . '</div>'. "\n";
	endif;

}
endif;

if ( ! function_exists( 'pinpoint_posted_on' ) ) :
/**
 * Prints HTML with meta information for the current post-date/time and author.
 *
 * @since 1.0.0
 */
function pinpoint_posted_on() {
	?>
	<?php

	$time_string = '<time class="entry-date published" datetime="%1$s">%2$s</time>';

	$time_string = sprintf( $time_string,
		esc_attr( get_the_date( 'c' ) ),
		esc_html( human_time_diff( get_the_time( 'U' ), current_time( 'timestamp' ) ) )
	);

	printf( wp_kses_post( __( '<span class="posted-on">Posted %1$s ago</span><span class="byline"> by %2$s</span>', 'pinpoint' ) ),
		sprintf( '<a href="%1$s" rel="bookmark">%2$s</a>',
			esc_url( get_permalink() ),
			$time_string
		),
		sprintf( '<span class="author vcard"><a class="url fn n" href="%1$s"><span itemprop="name">%2$s</span></a></span>',
			esc_url( get_author_posts_url( get_the_author_meta( 'ID' ) ) ),
			esc_html( get_the_author() )
		)
	);
}
endif;

if ( ! function_exists( 'pinpoint_categorized_blog' ) ) :
/**
 * Returns true if a blog has more than 1 category.
 *
 * @since  1.0.0
 * @return bool
 */
function pinpoint_categorized_blog() {
	if ( false === ( $all_the_cool_cats = get_transient( 'pinpoint_categories' ) ) ) {
		// Create an array of all the categories that are attached to posts.
		$all_the_cool_cats = get_categories( array(
			'fields'     => 'ids',
			'hide_empty' => 1,

			// We only need to know if there is more than one category.
			'number'     => 2,
		) );

		// Count the number of categories that are attached to the posts.
		$all_the_cool_cats = count( $all_the_cool_cats );

		set_transient( 'pinpoint_categories', $all_the_cool_cats );
	}

	if ( $all_the_cool_cats > 1 ) {
		// This blog has more than 1 category so pinpoint_categorized_blog should return true.
		return true;
	} else {
		// This blog has only 1 category so pinpoint_categorized_blog should return false.
		return false;
	}
}
endif;

if ( ! function_exists( 'pinpoint_category_transient_flusher' ) ) :
/**
 * Flush out the transients used in pinpoint_categorized_blog.
 *
 * @since 1.0.0
 */
function pinpoint_category_transient_flusher() {
	if ( defined( 'DOING_AUTOSAVE' ) && DOING_AUTOSAVE ) {
		return;
	}
	// Like, beat it. Dig?
	delete_transient( 'pinpoint_categories' );
}
endif;
add_action( 'edit_category', 'pinpoint_category_transient_flusher' );
add_action( 'save_post',     'pinpoint_category_transient_flusher' );

if ( ! function_exists( 'pinpoint_entry_share' ) ) :
/**
 * Social share.
 *
 * @since 1.0.0
 */
function pinpoint_entry_share() {

	// Get the data set in customizer
	$share  = get_theme_mod( 'pinpoint-post-share', 1 );

	if ( $share == 0 ) {
		return;
	}
	?>
		<div class="page-share text-center clearfix island bb">
			<div class="share-sites vertical-align horizontal-align">
				<div class="page-share-title micro hf text-uppercase muted"><?php esc_html_e( 'Share', 'pinpoint' ) ?></div>
				<a href="https://twitter.com/intent/tweet?text=<?php echo urlencode( esc_attr( get_the_title( get_the_ID() ) ) ); ?>&amp;url=<?php echo urlencode( get_permalink( get_the_ID() ) ); ?>" target="_blank"><i class="fa fa-twitter icon share-btn"></i><span class="sr-only">Twitter</span></a>
				<a href="https://www.facebook.com/sharer/sharer.php?u=<?php echo urlencode( get_permalink( get_the_ID() ) ); ?>" target="_blank"><i class="fa fa-facebook icon share-btn"></i><span class="sr-only">Facebook</span></a>
				<a href="https://plus.google.com/share?url=<?php echo urlencode( get_permalink( get_the_ID() ) ); ?>" target="_blank"><i class="fa fa-google-plus icon share-btn"></i><span class="sr-only">Google+</span></a>
				<a href="https://pinterest.com/pin/create/button/?url=<?php echo urlencode( get_permalink( get_the_ID() ) ); ?>&amp;media=<?php echo urlencode( wp_get_attachment_url( get_post_thumbnail_id( get_the_ID() ) ) ); ?>" target="_blank"><i class="fa fa-pinterest icon share-btn"></i><span class="sr-only">Pinterest</span></a>
			</div>
		</div>
	<?php
}
endif;

if ( ! function_exists( 'pinpoint_the_author' ) ) :
/**
 * Author post informations.
 *
 * @since  1.0.0
 */
function pinpoint_the_author() {

	// Get the data set in customizer
	$enable = get_theme_mod( 'pinpoint-the-author-box', 1 );

	// Disable if user choose it.
	if ( $enable == 0 ) {
		return;
	}

	// Bail if user hasn't fill the Biographical Info field.
	if ( ! get_the_author_meta( 'description' ) ) {
		return;
	}

	// Get the author social information.
	$twitter   = get_the_author_meta( 'twitter' );
	$facebook  = get_the_author_meta( 'facebook' );
	$gplus     = get_the_author_meta( 'gplus' );
	$instagram = get_the_author_meta( 'instagram' );
	$pinterest = get_the_author_meta( 'pinterest' );
	$linkedin  = get_the_author_meta( 'linkedin' );
	$dribbble  = get_the_author_meta( 'dribbble' );
?>

	<div class="author-bio">
		<div class="row vertical-align clearfix">

			<div class="intro vertical-align col-xs-12 col-md-8 pad-bottom">

				<div style="background: url( <?php echo esc_url( get_avatar_url( is_email( get_the_author_meta( 'user_email' ) ), apply_filters( 'pinpoint_the_author_avatar_size', 75 ), '', strip_tags( get_the_author() ) ) ) ?> ); background-size: cover" class="intro-img col-xs-12 left"></div>

				<div class="intro-text col-xs-12"><?php echo wp_kses_post( get_the_author_meta( 'description' ) ); ?></div>

			</div>

			<?php if ( $twitter || $facebook || $gplus || $instagram || $pinterest || $linkedin || $dribbble ) : ?>
				<div class="widget-socialmedia widget-socialmedia-top text-right col-xs-12 col-md-4 pad-bottom col-md-5">
					<ul class="authot-social-icons list-inline">
						<?php if ( $twitter ) { ?>
							<li><a class="muted" href="<?php echo esc_url( $twitter ) ?>"><i class="fa fa-twitter icon"></i><span class="sr-only">Twitter</span></a></li>
						<?php } ?>
						<?php if ( $facebook ) { ?>
							<li><a class="muted" href="<?php echo esc_url( $facebook ); ?>"><i class="fa fa-facebook icon"></i><span class="sr-only">Facebook</span></a></li>
						<?php } ?>
						<?php if ( $gplus ) { ?>
							<li><a class="muted" href="<?php echo esc_url( $gplus ); ?>"><i class="fa fa-google-plus icon"></i><span class="sr-only">Google+</span></a></li>
						<?php } ?>
						<?php if ( $instagram ) { ?>
							<li><a class="muted" href="<?php echo esc_url( $instagram ); ?>"><i class="fa fa-instagram icon"></i><span class="sr-only">Instagram</span></a></li>
						<?php } ?>
						<?php if ( $pinterest ) { ?>
							<li><a class="muted" href="<?php echo esc_url( $pinterest ); ?>"><i class="fa fa-pinterest-p icon"></i><span class="sr-only">Pinterest</span></a></li>
						<?php } ?>
						<?php if ( $linkedin ) { ?>
							<li><a class="muted" href="<?php echo esc_url( $linkedin ); ?>"><i class="fa fa-linkedin icon"></i><span class="sr-only">Linkedin</span></a></li>
						<?php } ?>
						<?php if ( $dribbble ) { ?>
							<li><a class="muted" href="<?php echo esc_url( $dribbble ); ?>"><i class="fa fa-dribbble icon"></i><span class="sr-only">Dribbble</span></a></li>
						<?php } ?>
					</ul>
				</div>
			<?php endif; ?>

		</div>
	</div><!-- .author-bio -->

<?php
}
endif;

if ( ! function_exists( 'pinpoint_comment' ) ) :
/**
 * Template for comments and pingbacks.
 *
 * Used as a callback by wp_list_comments() for displaying the comments.
 *
 * @since  1.0.0
 */
function pinpoint_comment( $comment, $args, $depth ) {
	$GLOBALS['comment'] = $comment;
	switch ( $comment->comment_type ) :
		case 'pingback' :
		case 'trackback' :
		// Display trackbacks differently than normal comments.
	?>
	<li <?php comment_class(); ?> id="comment-<?php comment_ID(); ?>">
		<article id="comment-<?php comment_ID(); ?>" class="comment-container">
			<p><?php esc_html_e( 'Pingback:', 'pinpoint' ); ?> <span><?php comment_author_link(); ?></span> <?php edit_comment_link( esc_html__( '(Edit)', 'pinpoint' ), '<span class="edit-link">', '</span>' ); ?></p>
		</article>
	<?php
			break;
		default :
		// Proceed with normal comments.
	?>
	<li <?php comment_class(); ?> id="li-comment-<?php comment_ID(); ?>">
		<article id="comment-<?php comment_ID(); ?>" class="comment-body">

			<footer class="comment-meta">
				<div class="comment-author vcard">
					<?php echo get_avatar( $comment, apply_filters( 'pinpoint_comment_avatar_size', 42 ) ); ?>
					<?php
						printf( '<b class="fn">%1$s</b><span class="says">%2$s</span>',
							get_comment_author_link(),
							esc_html__( ' says:', 'pinpoint' )
						);
					?>
				</div><!-- .comment-author -->

				<div class="comment-metadata meta micro text-uppercase sf pad-bottom">
					<?php
						$edit_comment_link = '';
							if ( get_edit_comment_link() )
								$edit_comment_link = sprintf( __( '&middot; %1$sEdit%2$s', 'pinpoint' ), '<a href="' . get_edit_comment_link() . '" title="' . esc_attr__( 'Edit Comment', 'pinpoint' ) . '">', '</a>' );

						printf( '<span class="date"><a href="%1$s"><time datetime="%2$s">%3$s</time></a> %4$s</span>',
							esc_url( get_comment_link( $comment->comment_ID ) ),
							get_comment_time( 'c' ),
							/* translators: 1: date, 2: time */
							sprintf( __( '%1$s at %2$s', 'pinpoint' ), get_comment_date(), get_comment_time() ),
							$edit_comment_link
						);
					?>
				</div><!-- .comment-metadata -->
			</footer><!-- .comment-meta -->

			<div class="comment-content">
				<?php if ( '0' == $comment->comment_approved ) : ?>
					<p class="comment-awaiting-moderation"><?php esc_html_e( 'Your comment is awaiting moderation.', 'pinpoint' ); ?></p>
				<?php endif; ?>
				<?php comment_text(); ?>
				<span class="reply">
					<?php comment_reply_link( array_merge( $args, array( 'reply_text' => __( '<i class="fa fa-reply"></i> Reply', 'pinpoint' ), 'depth' => $depth, 'max_depth' => $args['max_depth'] ) ) ); ?>
				</span><!-- .reply -->
			</div><!-- .comment-content -->

		</article><!-- #comment-## -->
	<?php
		break;
	endswitch; // end comment_type check
}
endif;

if ( ! function_exists( 'pinpoint_get_post_format_link_url' ) ) :
/**
 * Forked from hybrid_get_the_post_format_url.
 * Filters 'get_the_post_format_url' to make for a more robust and back-compatible function.  If WP did
 * not find a URL, check the post content for one.  If nothing is found, return the post permalink.
 * Used in Post Format Link
 *
 * @since 1.0.0
 */
function pinpoint_get_post_format_link_url( $url = '', $post = null ) {

	if ( empty( $url ) ) {

		$post = is_null( $post ) ? get_post() : $post;

		/* Catch links that are not wrapped in an '<a>' tag. */
		$content_url = preg_match( '/<a\s[^>]*?href=[\'"](.+?)[\'"]/is', make_clickable( $post->post_content ), $matches );

		$content_url = ! empty( $matches[1] ) ? esc_url_raw( $matches[1] ) : '';

		$url = ! empty( $content_url ) ? $content_url : get_permalink( get_the_ID() );
	}

	if ( $url ) {
	?>

		<a href="<?php echo esc_url( $url ); ?>" class="thumbnail-link">
			<div class="thumbnail-content">
				<div class="thumb-caption thumb-box text-center island-double">
					<h4>
						<?php if ( get_the_title() && ( __( '(Untitled)', 'pinpoint' ) != get_the_title() ) ) { ?>
							<?php the_title(); ?>
						<?php } else { ?>
							<?php echo esc_attr( $url ); ?>
						<?php }	?>
					</h4>
					<div class="small"><?php echo esc_url( $url ); ?></div>
				</div>
			</div>
		</a>

	<?php
	}

}
endif;

if ( ! function_exists( 'pinpoint_footer_text' ) ) :
/**
 * Footer Text
 *
 * @since  1.0.0
 */
function pinpoint_footer_text() {

	// Get the customizer data
	$default = 'Designed by <a href="https://www.theme-junkie.com/">Theme Junkie</a>';
	$footer_text = get_theme_mod( 'pinpoint-footer-text',  $default );

	// Polylang integration
	if ( is_polylang_activated() ) {
		$footer_text = pll__( get_theme_mod( 'pinpoint-footer-text', $default ) );
	}

	// Display the data
	echo '<p class="copyright">' . wp_kses_post( $footer_text ) . '</p>';

}
endif;
